@@ -4,7 +4,7 @@ from django.test import TestCase
 from ..models import Tag, TaggedItem
 from .factories import DummyModelFactory
 from .test_app.forms import DummyModelForm
-from .test_app.models import Dummy
+from .test_app.models import DummyModel
 
 
 class TaggingFormMixinTestCase(TestCase):
@@ -12,19 +12,19 @@ class TaggingFormMixinTestCase(TestCase):
     longMessage = True
 
     def setUp(self):
-        self.dummy = DummyModelFactory
+        self.dummy = DummyModelFactory()
         self.data = {
-            'charfield': 'foobar',
-            'tags': 'tagging, test'
+            'charfield': u'foobar',
+            'tags': u'tagging, test'
         }
 
     def test_mixin(self):
-        form = DummyModelForm(data=self.data)
+        form = DummyModelForm(data=self.data, instance=self.dummy)
         self.assertTrue(form.is_valid(), msg=(
             'The form should be valid. Errors: {0}'.format(form.errors)))
 
         form.save()
-        self.assertEqual(Dummy.objects.count(), 1, msg=(
+        self.assertEqual(DummyModel.objects.count(), 1, msg=(
             'The form should have saved one dummy.'))
         self.assertEqual(TaggedItem.objects.count(), 2, msg=(
             'The form should create one TaggedItem per entered tag.'))
